==> mono-1.1.7.tar.gz: mono-1.1.7/mcs/class/System/System.Net.Configuration/DefaultProxySection.cs <==
//
// System.Net.Configuration.DefaultProxySection.cs
//
// Authors:
//	Tim Coleman (tim@timcoleman.com)
//
// Copyright (C) Tim Coleman, 2004
// (c) 2004 Novell, Inc. (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0 && XML_DEP

using System.Configuration;

namespace System.Net.Configuration 
{
	public sealed class DefaultProxySection : ConfigurationSection
	{
		#region Fields

		ConfigurationPropertyCollection properties;
		static ConfigurationProperty bypassList = new ConfigurationProperty ("BypassList", typeof (BypassElementCollection), new BypassElementCollection ());
		static ConfigurationProperty module = new ConfigurationProperty ("Module", typeof (ModuleElement), new ModuleElement ());
		static ConfigurationProperty proxy = new ConfigurationProperty ("Proxy", typeof (ProxyElement), new ProxyElement ());

		#endregion // Fields

		#region Constructors

		public DefaultProxySection ()
		{
			properties = new ConfigurationPropertyCollection ();
			properties.Add (bypassList);
			properties.Add (module);
			properties.Add (proxy);
		}

		#endregion // Constructors

		#region Properties

		public BypassElementCollection BypassList {
			get { return (BypassElementCollection) base [bypassList]; }
		}

		public ModuleElement Module {
			get { return (ModuleElement) base [module]; }
		}

		protected internal override ConfigurationPropertyCollection Properties {
			get { return properties; }
		}

		public ProxyElement Proxy {
			get { return (ProxyElement) base [proxy]; }
		}

		#endregion // Properties

		#region Methods

		[MonoTODO]
		protected internal override object GetRuntimeObject ()
		{
			throw new NotImplementedException ();
		}

		#endregion // Methods
	}
}

#endif

==> mono-1.1.9.2.tar.gz: mono-1.1.9.2/mcs/class/System/System.Net.Configuration/DefaultProxySection.cs <==
//
// System.Net.Configuration.DefaultProxySection.cs
//
// Authors:
//	Tim Coleman (tim@timcoleman.com)
//
// Copyright (C) Tim Coleman, 2004
// (c) 2004 Novell, Inc. (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0 && CONFIGURATION_DEP

using System.Configuration;

namespace System.Net.Configuration 
{
	public sealed class DefaultProxySection : ConfigurationSection
	{
		#region Fields

		ConfigurationPropertyCollection properties;
		static ConfigurationProperty bypassList = new ConfigurationProperty ("BypassList", typeof (BypassElementCollection), new BypassElementCollection ());
		static ConfigurationProperty module = new ConfigurationProperty ("Module", typeof (ModuleElement), new ModuleElement ());
		static ConfigurationProperty proxy = new ConfigurationProperty ("Proxy", typeof (ProxyElement), new ProxyElement ());

		#endregion // Fields

		#region Constructors

		public DefaultProxySection ()
		{
			properties = new ConfigurationPropertyCollection ();
			properties.Add (bypassList);
			properties.Add (module);
			properties.Add (proxy);
		}

		#endregion // Constructors

		#region Properties

		public BypassElementCollection BypassList {
			get { return (BypassElementCollection) base [bypassList]; }
		}

		public ModuleElement Module {
			get { return (ModuleElement) base [module]; }
		}

		protected override ConfigurationPropertyCollection Properties {
			get { return properties; }
		}

		public ProxyElement Proxy {
			get { return (ProxyElement) base [proxy]; }
		}

		#endregion // Properties

		#region Methods

		[MonoTODO]
		protected override object GetRuntimeObject ()
		{
			throw new NotImplementedException ();
		}

		#endregion // Methods
	}
}

#endif
